@@ -120,20 +120,17 @@ class Quip:
         parser_icon.add_argument('--generate', '-g', action='store_true',
                              help='generate new icon')
 
-        parser_icon = subparsers.add_parser('clean', aliases=CLEAN_ACTION[1:], help='Clears the dist folders')
-        parser_icon.add_argument('name', nargs="?", help='name of the project')
+        parser_clean = subparsers.add_parser('clean', aliases=CLEAN_ACTION[1:], help='Clears the dist folders')
+        parser_clean.add_argument('name', nargs="?", help='name of the project')
 
-        parser_icon = subparsers.add_parser('setup', help='Setup External Systems')
-        parser_icon.add_argument('name', nargs="?", help='name of the project')
-
-        parser_icon = subparsers.add_parser('version', help='shows the version of the template/extension')
-        parser_icon.add_argument('version_method', nargs="?", choices=["minor", "major", "release"], help='update the version of the project. Options: minor,major,release.')
-        parser_icon.add_argument('--force', dest="forced_version", help='Force to change the version in all possible files')
-
-
-        parser_icon = subparsers.add_parser('config', help='show the configuration')
+        parser_setup = subparsers.add_parser('setup', help='Setup External Systems')
+        parser_setup.add_argument('name', nargs="?", help='name of the project')
 
+        parser_version = subparsers.add_parser('version', help='shows the version of the template/extension')
+        parser_version.add_argument('version_method', nargs="?", choices=["minor", "major", "release"], help='update the version of the project. Options: minor,major,release.')
+        parser_version.add_argument('--force', dest="forced_version", help='Force to change the version in all possible files')
 
+        parser_config = subparsers.add_parser('config', help='show the configuration')
 
         args = parser.parse_args()
         print(args)
@@ -165,9 +162,8 @@ class Quip:
 
         if "template" in dir(args) and args.template == False and args.name.startswith("ut-"):
             args.template = True
-        else:
-            args.template = False
-
+        
+        logging.info(f"The project is template={args.template}")
         return args
     
     def main(self):
@@ -708,7 +704,7 @@ class Quip:
             jnks_groups = jnks_config.get("groups", {})
             jnks_group_name, jnks_repository_name = external.parse_repository_full_path(repository_name, gl_groups, jnks_groups)
             
-            self.setup_jenkins(jnks, jnks_group_name, jnks_repository_name, gl.base_url)
+            self.setup_jenkins(jnks, jnks_group_name, jnks_repository_name, gl.base_url, repository_name)
             
         # create webhook for Jenkins
         if gl_config is not None and jnks_config is not None:
@@ -749,14 +745,15 @@ class Quip:
         gl.repository_name = repository_name
         return gl
     
-    def setup_jenkins(self, jnks, jnks_group_name, jnks_repository_name, gitlab_url):
+    def setup_jenkins(self, jnks, jnks_group_name, jnks_repository_name, gitlab_url, repository_name):
+        logging.debug(f"Group: {jnks_group_name}, Repository: {jnks_repository_name}")
         # Check if Jenkins Pipeline exists
         if jnks.check_job_exists(jnks_group_name, jnks_repository_name):
             cprint(f"Job exists in Jenkins: {jnks_group_name}/{jnks_repository_name}", "magenta")
         else:
             logging.info(f"Repository doesn't exist and will be created. {jnks_group_name}/{jnks_repository_name}")
             if yes_or_no("Do you want to create Jenkins Job?", default=True):
-                jnks.create_job(jnks_group_name, jnks_repository_name, self.project_name, gitlab_url)
+                jnks.create_job(jnks_group_name, jnks_repository_name, self.project_name, gitlab_url, repository_name)
                 cprint(f"Jenkins job created: {jnks_group_name}/{jnks_repository_name}", "green")
 
     def create_sonarqube(self, group_name, repository_name, sq_config):
